﻿using ModuleTools.Attributes;
using ModuleTools.Interfaces;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Runtime.Serialization;

namespace DatabaseCore.Models.Department
{
	/// <summary>
	/// Класс, описывающий учебный план кафедры
	/// </summary>
	[DataContract]
	[EntityDescription("AcademicPlan", "Учебный план кафедры")]
	[EntityDependency("EducationDirection", "EducationDirectionId", "Направление, к которму относится учебный план")]
	public class AcademicPlan : BaseEntity, IEntitySecurityExtenstion<AcademicPlan>
    {
        [DataMember]
		[MapConfiguration("EducationDirectionId")]
		public Guid? EducationDirectionId { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("YearEntrance")]
		public int YearEntrance { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("YearFinish")]
		public int YearFinish { get; set; }

		//-------------------------------------------------------------------------

		public virtual EducationDirection EducationDirection { get; set; }

		//-------------------------------------------------------------------------

		[ForeignKey("AcademicPlanId")]
		public virtual List<AcademicPlanRecord> AcademicPlanRecords { get; set; }

		//-------------------------------------------------------------------------

		public AcademicPlan SecurityCheck(AcademicPlan entity, bool allowFullData) => entity;
    }
}