﻿using ModuleTools.Attributes;
using ModuleTools.Interfaces;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Runtime.Serialization;

namespace DatabaseCore.Models.Department
{
	/// <summary>
	/// Класс, описывающий запись учебного плана кафедры
	/// </summary>
	[DataContract]
	[EntityDescription("AcademicPlanRecord", "Запись учебного плана кафедры")]
	[EntityDependency("AcademicPlan", "AcademicPlanId", "Учебный план, к которму относится запись")]
	[EntityDependency("Discipline", "DisciplineId", "Дисциплина, которая указана в записи плана")]
	public class AcademicPlanRecord : BaseEntity, IEntitySecurityExtenstion<AcademicPlanRecord>
	{
		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("AcademicPlanId")]
		public Guid AcademicPlanId { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("DisciplineId")]
		public Guid DisciplineId { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("InDepartment")]
		public bool InDepartment { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("Semester")]
		public int Semester { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("Zet")]
		public int Zet { get; set; }

		[DataMember]
		[MapConfiguration("AcademicPlanRecordParentId")]
		public Guid? AcademicPlanRecordParentId { get; set; }

		[DataMember]
		[MapConfiguration("IsParent")]
		public bool IsParent { get; set; }

		[DataMember]
		[MapConfiguration("IsFacultative")]
		public bool IsFacultative { get; set; }

		//-------------------------------------------------------------------------

		public virtual AcademicPlan AcademicPlan { get; set; }

		public virtual Discipline Discipline { get; set; }

		//-------------------------------------------------------------------------

		[ForeignKey("AcademicPlanRecordId")]
		public virtual List<AcademicPlanRecordTimeNormHour> AcademicPlanRecordTimeNormHours { get; set; }

		//-------------------------------------------------------------------------

		public AcademicPlanRecord SecurityCheck(AcademicPlanRecord entity, bool allowFullData) => entity;
	}
}