﻿using ModuleTools.Attributes;
using ModuleTools.Interfaces;
using System;
using System.ComponentModel.DataAnnotations;
using System.Runtime.Serialization;

namespace DatabaseCore.Models.Department
{
	/// <summary>
	/// Класс, описывающий аудиторию кафедры
	/// </summary>
	[DataContract]
	[EntityDescription("Classroom", "Аудитрия кафедры")]
	[EntityDependency("Employee", "EmployeeId", "Сотрудник, отвечающий за аудиторию")]
	public class Classroom : BaseEntity, IEntitySecurityExtenstion<Classroom>
	{
		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("Number")]
		public string Number { get; set; }

		[DataMember]
		[MapConfiguration("Title")]
		public string Title { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("EmployeeId")]
		public Guid EmployeeId { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("ClassroomType")]
		public int ClassroomType { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("Square")]
		public decimal Square { get; set; }

		[DataMember]
		[Required(ErrorMessage = "required")]
		[MapConfiguration("Capacity")]
		public int Capacity { get; set; }

		[DataMember]
		[MapConfiguration("SecurityCode")]
		public string SecurityCode { get; set; }

		[DataMember]
		[MapConfiguration("HaveProjector")]
		public bool HaveProjector { get; set; }

		[DataMember]
		[MapConfiguration("Description")]
		public string Description { get; set; }

		[DataMember]
		[MapConfiguration("Photo")]
		public byte[] Photo { get; set; }

		//-------------------------------------------------------------------------

		public virtual Employee Employee { get; set; }

		//-------------------------------------------------------------------------

		//-------------------------------------------------------------------------

		public Classroom SecurityCheck(Classroom entity, bool allowFullData)
		{
			if (!allowFullData)
			{
				entity.SecurityCode = "скрыто";
			}

			return entity;
		}
	}
}