﻿using DatabaseCore.Models.Security;
using ModuleTools.Attributes;
using ModuleTools.Interfaces;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;
using System.Runtime.Serialization;

namespace DatabaseCore.Models.Department
{
	/// <summary>
	/// Класс, описывающий преподавателя
	/// </summary>
	[DataContract]
	[EntityDescription("Lecturer", "Преподаваетль кафедры")]
	[EntityDependency("User", "UserId", "К какому пользователю относится преподаватель")]
	[EntityDependency("LecturerAcademicRank", "LecturerAcademicRankId", "Какое звание имеет преподаватель")]
	[EntityDependency("LecturerAcademicDegree", "LecturerAcademicDegreeId", "Какую степень имеет преподаватель")]
	public class Lecturer : BaseEntity, IEntitySecurityExtenstion<Lecturer>
    {
        [DataMember]
        [Required]
        [MapConfiguration("UserId")]
        public Guid UserId { get; set; }

        [DataMember]
        [MapConfiguration("LecturerAcademicRankId")]
        public Guid? LecturerAcademicRankId { get; set; }

        [DataMember]
        [MapConfiguration("LecturerAcademicDegreeId")]
        public Guid? LecturerAcademicDegreeId { get; set; }

        [DataMember]
        [Required]
        [MapConfiguration("LastName")]
        public string LastName { get; set; }

        [DataMember]
        [Required]
        [MapConfiguration("FirstName")]
        public string FirstName { get; set; }

        [DataMember]
        [MapConfiguration("Patronymic")]
        public string Patronymic { get; set; }

        [DataMember]
        [MapConfiguration("Abbreviation")]
        public string Abbreviation { get; set; }

        [DataMember]
        [Required]
        [MapConfiguration("DateBirth")]
        public DateTime DateBirth { get; set; }

        [DataMember]
        [Required]
        [MapConfiguration("Address")]
        public string Address { get; set; }

        [DataMember]
        [Required]
        [MapConfiguration("Email")]
        public string Email { get; set; }

        [DataMember]
        [Required]
        [MapConfiguration("MobileNumber")]
        public string MobileNumber { get; set; }

        [DataMember]
        [MapConfiguration("HomeNumber")]
        public string HomeNumber { get; set; }

        [DataMember]
        [MapConfiguration("Description")]
        public string Description { get; set; }

        [DataMember]
        [MapConfiguration("Photo")]
        public byte[] Photo { get; set; }

        [DataMember]
        [MapConfiguration("OnlyForPrivate")]
        public bool OnlyForPrivate { get; set; }

        [DataMember]
        [MapConfiguration("GroupElectricalSafety")]
        public string GroupElectricalSafety { get; set; }

        //-------------------------------------------------------------------------

        public virtual User User { get; set; }

        public virtual LecturerAcademicRank LecturerAcademicRank { get; set; }

        public virtual LecturerAcademicDegree LecturerAcademicDegree { get; set; }

        //-------------------------------------------------------------------------

        [ForeignKey("LecturerId")]
        public virtual List<LecturerPost> LecturerPosts { get; set; }

        [ForeignKey("LecturerId")]
        public virtual List<EducationDirection> EducationDirections { get; set; }

        //-------------------------------------------------------------------------

        public Lecturer SecurityCheck(Lecturer entity, bool allowFullData)
        {
            if (!allowFullData)
            {
                entity.DateBirth = DateTime.Now;
                entity.Address = "скрыто";
                entity.Email = "скрыто";
                entity.MobileNumber = "скрыто";
                entity.HomeNumber = "скрыто";
                entity.Photo = null;
            }

            return entity;
        }
    }
}