﻿using DesktopTools.Interfaces;
using System;
using System.Windows.Forms;

namespace DesktopTools.BaseControls
{
	/// <summary>
	/// Контрол, предоставляющий работу с целочисленным полем
	/// </summary>
	public partial class BaseControlInt : AbstractBaseControl, IBaseControl
	{
		/// <summary>
		/// Конструктор
		/// </summary>
		/// <param name="propertyName"></param>
		/// <param name="mustFilling"></param>
		/// <param name="readOnly"></param>
		/// <param name="minValue"></param>
		/// <param name="maxValue"></param>
		public BaseControlInt(string propertyName, bool mustFilling, bool readOnly, decimal minValue, decimal maxValue) : base(propertyName, mustFilling, readOnly)
		{
			InitializeComponent();
			_baseControl = this;

			numericUpDown.ValueChanged += (object sender, EventArgs e) => { CallOnValueChangeEvent(); };
			if (minValue != 0)
			{
				numericUpDown.Minimum = minValue;
			}
			if (maxValue != 0)
			{
				numericUpDown.Maximum = maxValue;
			}
			panelControl.Controls.Add(numericUpDown);

			if (!_mustFilling)
			{
				checkBoxNullable.CheckedChanged += (object sender, EventArgs e) =>
				{
					numericUpDown.Enabled = !(sender as CheckBox).Checked;
					CallOnValueChangeEvent();
				};
				panelControl.Controls.Add(checkBoxNullable);
			}
		}

		public void SetDefaultValue() => _originalValue = _mustFilling ? 0 : null;

		public void SetValueToControl(object value)
		{
			if (value != null)
			{
				numericUpDown.Value = Convert.ToInt32(value);
			}
			else if (!_mustFilling)
			{
				checkBoxNullable.Checked = true;
			}
		}

		public void DropValueForControl()
		{
			if (_originalValue != null)
			{
				numericUpDown.Value = Convert.ToInt32(_originalValue);
			}
			else if (!_mustFilling)
			{
				checkBoxNullable.Checked = true;
			}
		}

		public bool CheckValueForControl() => true;

		public object GetValueFromControl() => !_mustFilling && checkBoxNullable.Checked ? null : Convert.ToInt32(numericUpDown.Value);

		public string GetPropertyName() => _propertyName;
	}
}