﻿using DepartmentBusinessLogic.Enums;
using ModuleTools.Attributes;
using ModuleTools.BindingModels;
using System;
using System.ComponentModel.DataAnnotations;

namespace DepartmentBusinessLogic.BindingModels
{
    /// <summary>
    /// Получение аудитории
    /// </summary>
    public class ClassroomGetBindingModel : GetBindingModel
    {
        /// <summary>
        /// Используется для вывода в расписании 
        /// </summary>
        public bool? UseInSchedule { get; set; }

        /// <summary>
        /// Вывод аудиторий, закрепленных за сотрудником
        /// </summary>
        public Guid? EmployeeId { get; set; }
    }

    /// <summary>
    /// Сохранение аудитории
    /// </summary>
    public class ClassroomSetBindingModel : SetBindingModel
    {
        [Required(ErrorMessage = "required")]
        [MapConfiguration("Number")]
        public string Number { get; set; }

        [MapConfiguration("Title")]
        public string Title { get; set; }

        [Required(ErrorMessage = "required")]
        [MapConfiguration("EmployeeId")]
        public Guid EmployeeId { get; set; }

        [Required(ErrorMessage = "required")]
        [MapConfiguration("ClassroomType")]
        public ClassroomType ClassroomType { get; set; }

        [Required(ErrorMessage = "required")]
        [MapConfiguration("Square")]
        public decimal Square { get; set; }

        [Required(ErrorMessage = "required")]
        [MapConfiguration("Capacity")]
        public int Capacity { get; set; }

        [MapConfiguration("SecurityCode")]
        public string SecurityCode { get; set; }

        [MapConfiguration("HaveProjector")]
        public bool HaveProjector { get; set; }

        [MapConfiguration("Description")]
        public string Description { get; set; }

        [MapConfiguration("Photo")]
        public byte[] Photo { get; set; }
    }
}